@@ -236,9 +236,12 @@ int receive_fam_notifications(FAMConnection *c, int time_limit)
 		}
 		//printf("altered filename=%s\n",altered_filename);
 
-		retval = stat(altered_filename,&altered_statbuf);
-		if (retval < 0) //yet another disappearing file.
-			continue;
+		if (e.code != FAMDeleted)
+		{
+			retval = stat(altered_filename,&altered_statbuf);
+			if (retval < 0) //yet another disappearing file.
+				continue;
+		}
 
 		if (((!(arguments.showchanged)) && (arguments.showcreated) && (e.code == FAMCreated) && (!(S_ISDIR(altered_statbuf.st_mode)))) ||
 				((arguments.showchanged) && (e.code == FAMChanged) && (arguments.filechangetimeout < 0) && (!(S_ISDIR(altered_statbuf.st_mode)))))
@@ -282,11 +285,27 @@ int receive_fam_notifications(FAMConnection *c, int time_limit)
 			//printf("hey new directory!!\n");
 			monitor_file(c,altered_filename);
 		}
-		else if ((arguments.showdeleted) && (e.code == FAMDeleted) && (!(S_ISDIR(altered_statbuf.st_mode))))
+		else if ((arguments.showdeleted) && (e.code == FAMDeleted))
 		{
-			if (arguments.showaction)
-				snprintf(actionname,sizeof(actionname),"deleted ");
-			printf("%s%s\n",actionname,altered_filename);
+			//
+			//if this isn't a directory i'm monitoring then it must be a file.
+			//unfortunately the file isn't around anymore to do a stat on.
+			//so it's kinda hard to tell if it's a directory or not
+			//the only thing left to do is check to see if it's a dir that
+			//we're already monitoring.
+			//
+			char possible_directory_filename[FILENAME_MAX];
+			filenode_type directory_node;
+			void *ptr;
+			snprintf(possible_directory_filename,sizeof(possible_directory_filename),"%s/%s",filenode->filename,e.filename);
+			directory_node.filename = possible_directory_filename;
+			ptr=avl_find(filetree,(void*)&directory_node);
+			if (!ptr) //whoo hoo!  it's not a directory (that we're monitoring)
+			{
+				if (arguments.showaction)
+					snprintf(actionname,sizeof(actionname),"deleted ");
+				printf("%s%s\n",actionname,altered_filename);
+			}
 		}
 		else if ((arguments.showexecuting) && (e.code == FAMStartExecuting) && (!(S_ISDIR(altered_statbuf.st_mode))))
 		{
